@@ -60,7 +60,7 @@ typedef struct {
 } SoupClientMessageIOHTTP1;
 
 #define RESPONSE_BLOCK_SIZE 8192
-#define HEADER_SIZE_LIMIT (100 * 1024)
+#define HEADER_SIZE_LIMIT (64 * 1024)
 
 static void
 soup_message_io_http1_free (SoupMessageIOHTTP1 *msg_io)
@@ -568,8 +568,7 @@ io_read (SoupClientMessageIOHTTP1 *client_io,
                          * closed when we're done.
                          */
                         soup_message_headers_append_common (soup_message_get_request_headers (msg),
-                                                            SOUP_HEADER_CONNECTION, "close",
-                                                            SOUP_HEADER_VALUE_TRUSTED);
+                                                            SOUP_HEADER_CONNECTION, "close");
                         soup_message_set_metrics_timestamp (msg, SOUP_MESSAGE_METRICS_RESPONSE_END);
                         io->read_state = SOUP_MESSAGE_IO_STATE_FINISHING;
                         break;
@@ -974,7 +973,6 @@ soup_client_message_io_http1_run_until_read_async (SoupClientMessageIO *iface,
         GTask *task;
 
         task = g_task_new (msg, cancellable, callback, user_data);
-        g_task_set_source_tag (task, soup_client_message_io_http1_run_until_read_async);
         g_task_set_priority (task, io_priority);
         io_run_until_read_async (io, task);
 }
